"use client";

import { useState } from "react";
import { usePathname } from "next/navigation";
import Link from "next/link";
import { cn } from "@/lib/utils";
import { Button } from "@/components/ui/button";
import { useAuth } from "@/lib/hooks/useAuth";
import { Role } from "@/lib/types";
import {
  Users,
  UserCog,
  BookOpen,
  CalendarCheck,
  BarChart3,
  Settings,
  Menu,
  X,
  Home,
  Bell,
} from "lucide-react";
import Image from "next/image";

const routes = [
  {
    label: "Dashboard",
    icon: Home,
    href: "/dashboard",
    roles: ["admin", "teacher", "student"],
  },
  {
    label: "Students",
    icon: Users,
    href: "/students",
    roles: ["admin", "teacher"],
  },
  {
    label: "Teachers",
    icon: UserCog,
    href: "/teachers",
    roles: ["admin"],
  },
  {
    label: "Classes",
    icon: BookOpen,
    href: "/classes",
    roles: ["admin", "teacher", "student"],
  },
  {
    label: "Attendance",
    icon: CalendarCheck,
    href: "/attendance",
    roles: ["admin", "teacher"],
  },
  {
    label: "Reports",
    icon: BarChart3,
    href: "/reports",
    roles: ["admin"],
  },
  {
    label: "Settings",
    icon: Settings,
    href: "/settings",
    roles: ["admin", "teacher", "student"],
  },
];

export function Sidebar() {
  const pathname = usePathname();
  const { user } = useAuth();
  const [isOpen, setIsOpen] = useState(false);
  
  const role = user?.role || "student";

  const filteredRoutes = routes.filter((route) => 
    route.roles.includes(role as Role)
  );

  const toggleSidebar = () => {
    setIsOpen(!isOpen);
  };

  return (
    <>
      {/* Mobile Menu Button */}
      <Button
        variant="ghost"
        size="icon"
        className="lg:hidden fixed top-4 left-4 z-50"
        onClick={toggleSidebar}
      >
        {isOpen ? <X size={24} /> : <Menu size={24} />}
      </Button>

      {/* Sidebar */}
      <div
        className={cn(
          "fixed inset-y-0 left-0 z-40 w-64 bg-background border-r border-border transition-transform duration-300 ease-in-out transform",
          isOpen ? "translate-x-0" : "-translate-x-full lg:translate-x-0"
        )}
      >
        <div className="h-full flex flex-col">
          <div className="px-4 py-6 border-b border-border text-center">
            <div className="flex flex-col items-center space-y-2">
              <Image
                src="/logo1.png"
                alt="Dadaz Logo"
                width={120}
                height={50}
                className="h-20 w-auto"
              />
              <h1 className="text-2xl font-bold text-primary">Dadaz Center</h1>
              <p className="text-sm text-muted-foreground">Management System</p>
            </div>
          </div>

          <div className="flex-1 py-4 overflow-y-auto">
            <nav className="px-2 space-y-1">
              {filteredRoutes.map((route) => (
                <Link
                  key={route.href}
                  href={route.href}
                  className={cn(
                    "flex items-center px-4 py-3 text-sm rounded-md transition-colors",
                    pathname === route.href
                      ? "bg-primary text-primary-foreground"
                      : "text-foreground hover:bg-muted"
                  )}
                  onClick={() => setIsOpen(false)}
                >
                  <route.icon className="mr-3 h-5 w-5" />
                  {route.label}
                </Link>
              ))}
            </nav>
          </div>

          <div className="p-4 border-t border-border">
        {user ? (
          <div className="flex items-center">
            {/* Profile picture or initial */}
            <div className="mr-2">
              {user.profileUrl ? (
                <img
                  src={user.profileUrl}
                  alt={user.name}
                  className="w-8 h-8 rounded-full object-cover"
                />
              ) : (
                <div className="w-8 h-8 rounded-full bg-primary text-primary-foreground flex items-center justify-center">
                  {user.name.charAt(0)}
                </div>
              )}
            </div>

            {/* User info */}
            <div>
              <p className="text-sm font-medium">{user.name}</p>
              <p className="text-xs text-muted-foreground capitalize">{user.role}</p>
            </div>
          </div>
        ) : (
          <Link href="/auth">
            <Button variant="outline" className="w-full">
              Sign in
            </Button>
          </Link>
        )}
      </div>
        </div>
      </div>
    </>
  );
}